@@ -54,7 +54,7 @@ public:
     }
 
     KEBApp(const QString &bookmarksFile, bool readonly, const QString &address, bool browser, const QString &caption, const QString &dbusObjectName);
-    virtual ~KEBApp();
+    ~KEBApp() override;
 
     void reset(const QString &caption, const QString &bookmarksFileName);
 
@@ -62,14 +62,12 @@ public:
     SelcAbilities getSelectionAbilities() const;
     void setActionsEnabled(SelcAbilities);
 
-    QMenu *popupMenuFactory(const char *type)
+    QMenu *popupMenuFactory(const QString &type)
     {
         QWidget *menu = factory()->container(type, this);
         return dynamic_cast<QMenu *>(menu);
     }
 
-    KToggleAction *getToggleAction(const char *) const;
-
     QString caption() const
     {
         return m_caption;
